package com.zayac.changeurl.service;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.ReUtil;
import cn.hutool.core.util.StrUtil;
import com.zayac.changeurl.common.Constant;
import com.zayac.changeurl.entity.*;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import java.util.*;


/**
 * @author zayac
 * @since 2023-08-30 12:08
 */
@Service
public class ChangeURLServiceImpl implements ChangeURLService {
    private static final String KYJS = "ky.js";
    private static final String HTHJS = "hth.js";

    @Override
    public Boolean change(String text) {
        //如果传入参数为空,返回修改失败
        if (StrUtil.isEmpty(text)) {
            return false;
        }
        String[] arr = text.split("\n");

        //传入text 包含SEO 专用域名 则为开云
        if (text.contains("SEO 专用域名")) {
            KyMsgEntity kyMsg = new KyMsgEntity(arr);
            List<String> kyTargets = new ArrayList<>();
            kyTargets.add(KYJS);

            KyTemplateEntity kyTemplate =
                    new KyTemplateEntity(
                            "kyApp1",
                            "kyApp2",
                            "kyPc1",
                            "kyPc2",
                            "kyH51",
                            "kyH52",
                            "ky.js.template",
                            kyTargets);
            //读取模板文件
            String template = loadTemplate(kyTemplate.getTemplatePath());
            template = template
                    .replace(kyTemplate.getApp1(), kyMsg.getApp().get(0))
                    .replace(kyTemplate.getApp2(), kyMsg.getApp().get(1))
                    .replace(kyTemplate.getH51(), kyMsg.getH5().get(0))
                    .replace(kyTemplate.getH52(), kyMsg.getH5().get(1))
                    .replace(kyTemplate.getPc1(), kyMsg.getPc().get(0))
                    .replace(kyTemplate.getPc2(), kyMsg.getPc().get(1));

            modifyFile(template, kyTemplate.getTargets());
            //读取修改过的文件 校验修改成功失败
            String result = FileUtil.readUtf8String(KYJS);
            //如果修改后的js文件中，
            return ReUtil.count(Constant.URL_PATTERN, result) >= 6;
        } else {
            HthMsgEntity hthMsg = new HthMsgEntity(arr);
            List<String> hthTargets = new ArrayList<>();
            hthTargets.add(HTHJS);
            HthTemplateEntity hthTemplate = new HthTemplateEntity("hthApp", "hthtyApp", "hthPc", "hthH5", "hth.js.template", hthTargets);
            //读取模板文件
            String template = loadTemplate(hthTemplate.getTemplatePath());
            template = template
                    .replace(hthTemplate.getApp1(), hthMsg.getApp())
                    .replace(hthTemplate.getApp2(), hthMsg.getTyApp())
                    .replace(hthTemplate.getPc(), hthMsg.getPc())
                    .replace(hthTemplate.getH5(), hthMsg.getH5());
            modifyFile(template, hthTemplate.getTargets());
            //读取修改过的文件 校验修改成功失败
            String result = FileUtil.readUtf8String(HTHJS);
            //如果修改后的js文件中，
            return ReUtil.count(Constant.URL_PATTERN, result) >= 4;

        }

    }

    /**
     * 从模板文件中读取文件
     *
     * @param path 文件路径
     * @return js文件模板中行List
     */
    @Cacheable("template")
    public String loadTemplate(String path) {
        if (FileUtil.exist(path)) {
            return FileUtil.readUtf8String(path);
        } else {
            throw new RuntimeException("模板文件不存在");
        }
    }

    public void modifyFile(String text, List<String> paths) {
        for (String target : paths) {
            if (FileUtil.exist(target)) {
                FileUtil.del(target);
            } else {
                FileUtil.newFile(target);
            }
            FileUtil.writeString(text, target, "UTF-8");
        }
    }
}
